{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-tools/awscli:1.0"
                },
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envName": "AWS_CONFIG_FILE",
                            "envValue": "$(inputs.aws_config.path)"
                        },
                        {
                            "envName": "AWS_SHARED_CREDENTIALS_FILE",
                            "envValue": "$(inputs.aws_shared_credentials.path)"
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#awscli_upload.cwl/aws_config"
                },
                {
                    "type": "File",
                    "id": "#awscli_upload.cwl/aws_shared_credentials"
                },
                {
                    "type": "File",
                    "id": "#awscli_upload.cwl/input"
                },
                {
                    "type": "string",
                    "id": "#awscli_upload.cwl/s3_endpoint"
                },
                {
                    "type": "string",
                    "id": "#awscli_upload.cwl/s3_profile"
                },
                {
                    "type": "string",
                    "id": "#awscli_upload.cwl/s3uri"
                }
            ],
            "baseCommand": [],
            "stdout": "output",
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $('aws_upload.' + inputs.input.basename + '.time.json') aws --profile $(inputs.s3_profile) --endpoint-url $(inputs.s3_endpoint) --no-verify-ssl s3 cp $(inputs.input.path) $(inputs.s3uri)"
                }
            ],
            "id": "#awscli_upload.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output"
                    },
                    "id": "#awscli_upload.cwl/output"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('aws_upload.' + inputs.input.basename + '.time.json')"
                    },
                    "id": "#awscli_upload.cwl/time_metrics"
                }
            ]
        },
        {
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "class": "ExpressionTool",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": [
                            "null",
                            "File"
                        ]
                    },
                    "id": "#extract_outputs.cwl/file_array"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#extract_outputs.cwl/output"
                }
            ],
            "expression": "${\n  var trueFile = [];\n  for (var i = 0; i < inputs.file_array.length; i++){\n    if (inputs.file_array[i] != null){\n      trueFile.push(inputs.file_array[i])\n    }\n  };\n  return {'output': trueFile};\n}\n",
            "id": "#extract_outputs.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-exome-variant-detection/genomel_variant_calling:6.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk3_selectvariants.cwl/input_vcf"
                },
                {
                    "type": "string",
                    "id": "#gatk3_selectvariants.cwl/job_uuid"
                },
                {
                    "type": "string",
                    "id": "#gatk3_selectvariants.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#gatk3_selectvariants.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_prefix + '.filtered.site_only.vcf.gz')"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk3_selectvariants.cwl/output_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.gatk3_selectvariants.time.json')"
                    },
                    "id": "#gatk3_selectvariants.cwl/time_metrics"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.gatk3_selectvariants.time.json') java -Xmx100G -XX:ParallelGCThreads=30 -jar /opt/GenomeAnalysisTK.jar -T SelectVariants --variant $(inputs.input_vcf.path) -R $(inputs.reference.path) -o $(inputs.output_prefix + '.filtered.site_only.vcf.gz') -select \"QUAL > 20.0\" -ef -env"
                }
            ],
            "id": "#gatk3_selectvariants.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-exome-variant-detection/gatk4_1_0:1.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "gvcf_path.list",
                            "entry": "${\n  var paths = [];\n  for (var i = 0; i < inputs.gvcf_files.length; i++){\n    if (inputs.gvcf_files[i][\"nameext\"] == \".gz\"){\n      paths.push(inputs.gvcf_files[i][\"path\"])\n      }\n    }\n  return paths.join(\"\\n\")\n  }\n"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 30
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/bed_file"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 99,
                        "prefix": "-e"
                    },
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/cromwell_engine"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/gvcf_files"
                },
                {
                    "type": "string",
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/job_uuid"
                },
                {
                    "type": "int",
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/number_of_chunks"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/reference"
                },
                {
                    "type": "int",
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/thread_count"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.genomel_pdc_gatk4_cohort_genotyping.time.json')"
                    },
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/time_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/vcf_list"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "sed 's/\\\\\\\\n/\\\\n/g' gvcf_path.list > fixed_gvcf_path.list\n/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.genomel_pdc_gatk4_cohort_genotyping.time.json') python /opt/genomel_pdc_gatk4_cohort_genotyping.py --gvcf_path fixed_gvcf_path.list -j $(inputs.job_uuid) -f $(inputs.reference.path) -L $(inputs.bed_file.path) -n $(inputs.thread_count) -c $(inputs.number_of_chunks)"
                }
            ],
            "id": "#genomel_gatk4_cohort_genotyping.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-exome-variant-detection/genomel_variant_calling:3.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "bam_path.list",
                            "entry": "${\n  var paths = [];\n  for (var i = 0; i < inputs.bam_files.length; i++){\n    if (inputs.bam_files[i][\"nameext\"] == \".bam\"){\n      paths.push(inputs.bam_files[i][\"path\"])\n      }\n    }\n  return paths.join(\"\\n\")\n  }\n"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 30
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#genomel_pdc_freebayes.cwl/bam_files"
                },
                {
                    "type": "File",
                    "id": "#genomel_pdc_freebayes.cwl/bed_file"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 99,
                        "prefix": "-e"
                    },
                    "id": "#genomel_pdc_freebayes.cwl/cromwell_engine"
                },
                {
                    "type": "string",
                    "id": "#genomel_pdc_freebayes.cwl/job_uuid"
                },
                {
                    "type": "int",
                    "id": "#genomel_pdc_freebayes.cwl/number_of_chunks"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#genomel_pdc_freebayes.cwl/reference"
                },
                {
                    "type": "int",
                    "id": "#genomel_pdc_freebayes.cwl/thread_count"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.genomel_pdc_freebayes.time.json')"
                    },
                    "id": "#genomel_pdc_freebayes.cwl/time_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.vcf"
                    },
                    "id": "#genomel_pdc_freebayes.cwl/vcf_list"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "sed 's/\\\\\\\\n/\\\\n/g' bam_path.list > fixed_bam_path.list\n/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.genomel_pdc_freebayes.time.json') python /opt/genomel_pdc_freebayes.py -L fixed_bam_path.list -j $(inputs.job_uuid) -f $(inputs.reference.path) -t $(inputs.bed_file.path) -n $(inputs.thread_count) -c $(inputs.number_of_chunks)"
                }
            ],
            "id": "#genomel_pdc_freebayes.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-exome-variant-detection/genomel_variant_calling:6.0"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#picard_sortvcf.cwl/job_uuid"
                },
                {
                    "type": "string",
                    "id": "#picard_sortvcf.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "id": "#picard_sortvcf.cwl/reference_dict"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "I=",
                            "separate": false
                        }
                    },
                    "inputBinding": {
                        "position": 99
                    },
                    "id": "#picard_sortvcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.' + inputs.output_prefix + '.vcf.gz')"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_sortvcf.cwl/sorted_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.picard_sortvcf.time.json')"
                    },
                    "id": "#picard_sortvcf.cwl/time_metrics"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.picard_sortvcf.time.json') java -Xmx100G -XX:ParallelGCThreads=30 -jar /opt/picard.jar SortVcf CREATE_INDEX=true OUTPUT=$(inputs.job_uuid + '.' + inputs.output_prefix + '.vcf.gz') SEQUENCE_DICTIONARY=$(inputs.reference_dict.path)"
                }
            ],
            "id": "#picard_sortvcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/yilinxu/variant-ensembl:vArmyKnife"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#vArmyKnife_variant_ensemble.cwl/freebayes_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#vArmyKnife_variant_ensemble.cwl/gatk4_vcf"
                },
                {
                    "type": "string",
                    "id": "#vArmyKnife_variant_ensemble.cwl/job_uuid"
                },
                {
                    "type": "string",
                    "id": "#vArmyKnife_variant_ensemble.cwl/output_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#vArmyKnife_variant_ensemble.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#vArmyKnife_variant_ensemble.cwl/ensemble_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.vArmyKnife_variant_ensemble.time.json')"
                    },
                    "id": "#vArmyKnife_variant_ensemble.cwl/time_metrics"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.vArmyKnife_variant_ensemble.time.json') java -jar /opt/vArmyKnife.jar walkVcf --splitMultiAllelics --leftAlignAndTrim --genomeFA \"$(inputs.reference.path)\" --runEnsembleMerger --singleCallerVcfNames \"gatk4,freebayes\" --singleCallerPriority \"gatk4,freebayes\" --convertToStandardVcf \"$(inputs.gatk4_vcf.path);$(inputs.freebayes_vcf.path)\" \"$(inputs.output_name)\""
                }
            ],
            "id": "#vArmyKnife_variant_ensemble.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#freebayes.cwl/bam_files"
                },
                {
                    "type": "File",
                    "id": "#freebayes.cwl/bed_file"
                },
                {
                    "type": "boolean",
                    "id": "#freebayes.cwl/cromwell_engine"
                },
                {
                    "type": "string",
                    "id": "#freebayes.cwl/job_uuid"
                },
                {
                    "type": "int",
                    "id": "#freebayes.cwl/number_of_chunks"
                },
                {
                    "type": "string",
                    "id": "#freebayes.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#freebayes.cwl/reference"
                },
                {
                    "type": "int",
                    "id": "#freebayes.cwl/thread_count"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#freebayes.cwl/gatk3_selectvariants/output_vcf",
                    "id": "#freebayes.cwl/freebayes_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#freebayes.cwl/genomel_pdc_freebayes/time_metrics",
                    "id": "#freebayes.cwl/time_metrics_from_freebayes"
                },
                {
                    "type": "File",
                    "outputSource": "#freebayes.cwl/picard_sortvcf/time_metrics",
                    "id": "#freebayes.cwl/time_metrics_from_picard_sortvcf"
                },
                {
                    "type": "File",
                    "outputSource": "#freebayes.cwl/gatk3_selectvariants/time_metrics",
                    "id": "#freebayes.cwl/time_metrics_from_selectvariants"
                }
            ],
            "steps": [
                {
                    "run": "#gatk3_selectvariants.cwl",
                    "in": [
                        {
                            "source": "#freebayes.cwl/picard_sortvcf/sorted_vcf",
                            "id": "#freebayes.cwl/gatk3_selectvariants/input_vcf"
                        },
                        {
                            "source": "#freebayes.cwl/job_uuid",
                            "id": "#freebayes.cwl/gatk3_selectvariants/job_uuid"
                        },
                        {
                            "source": [
                                "#freebayes.cwl/job_uuid",
                                "#freebayes.cwl/output_prefix"
                            ],
                            "valueFrom": "$(self[0] + '.' + self[1] + '.freebayes')",
                            "id": "#freebayes.cwl/gatk3_selectvariants/output_prefix"
                        },
                        {
                            "source": "#freebayes.cwl/reference",
                            "id": "#freebayes.cwl/gatk3_selectvariants/reference"
                        }
                    ],
                    "out": [
                        "#freebayes.cwl/gatk3_selectvariants/output_vcf",
                        "#freebayes.cwl/gatk3_selectvariants/time_metrics"
                    ],
                    "id": "#freebayes.cwl/gatk3_selectvariants"
                },
                {
                    "run": "#genomel_pdc_freebayes.cwl",
                    "in": [
                        {
                            "source": "#freebayes.cwl/bam_files",
                            "id": "#freebayes.cwl/genomel_pdc_freebayes/bam_files"
                        },
                        {
                            "source": "#freebayes.cwl/bed_file",
                            "id": "#freebayes.cwl/genomel_pdc_freebayes/bed_file"
                        },
                        {
                            "source": "#freebayes.cwl/cromwell_engine",
                            "id": "#freebayes.cwl/genomel_pdc_freebayes/cromwell_engine"
                        },
                        {
                            "source": "#freebayes.cwl/job_uuid",
                            "id": "#freebayes.cwl/genomel_pdc_freebayes/job_uuid"
                        },
                        {
                            "source": "#freebayes.cwl/number_of_chunks",
                            "id": "#freebayes.cwl/genomel_pdc_freebayes/number_of_chunks"
                        },
                        {
                            "source": "#freebayes.cwl/reference",
                            "id": "#freebayes.cwl/genomel_pdc_freebayes/reference"
                        },
                        {
                            "source": "#freebayes.cwl/thread_count",
                            "id": "#freebayes.cwl/genomel_pdc_freebayes/thread_count"
                        }
                    ],
                    "out": [
                        "#freebayes.cwl/genomel_pdc_freebayes/vcf_list",
                        "#freebayes.cwl/genomel_pdc_freebayes/time_metrics"
                    ],
                    "id": "#freebayes.cwl/genomel_pdc_freebayes"
                },
                {
                    "run": "#picard_sortvcf.cwl",
                    "in": [
                        {
                            "source": "#freebayes.cwl/job_uuid",
                            "id": "#freebayes.cwl/picard_sortvcf/job_uuid"
                        },
                        {
                            "source": "#freebayes.cwl/output_prefix",
                            "valueFrom": "$(self + '.srt')",
                            "id": "#freebayes.cwl/picard_sortvcf/output_prefix"
                        },
                        {
                            "source": "#freebayes.cwl/reference",
                            "valueFrom": "$(self.secondaryFiles[1])",
                            "id": "#freebayes.cwl/picard_sortvcf/reference_dict"
                        },
                        {
                            "source": "#freebayes.cwl/genomel_pdc_freebayes/vcf_list",
                            "id": "#freebayes.cwl/picard_sortvcf/vcf"
                        }
                    ],
                    "out": [
                        "#freebayes.cwl/picard_sortvcf/sorted_vcf",
                        "#freebayes.cwl/picard_sortvcf/time_metrics"
                    ],
                    "id": "#freebayes.cwl/picard_sortvcf"
                }
            ],
            "id": "#freebayes.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#gatk4_cohort_genotyping.cwl/bed_file"
                },
                {
                    "type": "boolean",
                    "id": "#gatk4_cohort_genotyping.cwl/cromwell_engine"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk4_cohort_genotyping.cwl/gvcf_files"
                },
                {
                    "type": "string",
                    "id": "#gatk4_cohort_genotyping.cwl/job_uuid"
                },
                {
                    "type": "int",
                    "id": "#gatk4_cohort_genotyping.cwl/number_of_chunks"
                },
                {
                    "type": "string",
                    "id": "#gatk4_cohort_genotyping.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#gatk4_cohort_genotyping.cwl/reference"
                },
                {
                    "type": "int",
                    "id": "#gatk4_cohort_genotyping.cwl/thread_count"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#gatk4_cohort_genotyping.cwl/gatk3_selectvariants/output_vcf",
                    "id": "#gatk4_cohort_genotyping.cwl/gatk4_cohort_genotyping_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/time_metrics",
                    "id": "#gatk4_cohort_genotyping.cwl/time_metrics_from_gatk4_cohort_genotyping"
                },
                {
                    "type": "File",
                    "outputSource": "#gatk4_cohort_genotyping.cwl/picard_sortvcf/time_metrics",
                    "id": "#gatk4_cohort_genotyping.cwl/time_metrics_from_picard_sortvcf"
                },
                {
                    "type": "File",
                    "outputSource": "#gatk4_cohort_genotyping.cwl/gatk3_selectvariants/time_metrics",
                    "id": "#gatk4_cohort_genotyping.cwl/time_metrics_from_selectvariants"
                }
            ],
            "steps": [
                {
                    "run": "#gatk3_selectvariants.cwl",
                    "in": [
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/picard_sortvcf/sorted_vcf",
                            "id": "#gatk4_cohort_genotyping.cwl/gatk3_selectvariants/input_vcf"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/job_uuid",
                            "id": "#gatk4_cohort_genotyping.cwl/gatk3_selectvariants/job_uuid"
                        },
                        {
                            "source": [
                                "#gatk4_cohort_genotyping.cwl/job_uuid",
                                "#gatk4_cohort_genotyping.cwl/output_prefix"
                            ],
                            "valueFrom": "$(self[0] + '.' + self[1] + '.gatk4')",
                            "id": "#gatk4_cohort_genotyping.cwl/gatk3_selectvariants/output_prefix"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/reference",
                            "id": "#gatk4_cohort_genotyping.cwl/gatk3_selectvariants/reference"
                        }
                    ],
                    "out": [
                        "#gatk4_cohort_genotyping.cwl/gatk3_selectvariants/output_vcf",
                        "#gatk4_cohort_genotyping.cwl/gatk3_selectvariants/time_metrics"
                    ],
                    "id": "#gatk4_cohort_genotyping.cwl/gatk3_selectvariants"
                },
                {
                    "run": "#genomel_gatk4_cohort_genotyping.cwl",
                    "in": [
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/bed_file",
                            "id": "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/bed_file"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/cromwell_engine",
                            "id": "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/cromwell_engine"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/gvcf_files",
                            "id": "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/gvcf_files"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/job_uuid",
                            "id": "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/job_uuid"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/number_of_chunks",
                            "id": "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/number_of_chunks"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/reference",
                            "id": "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/reference"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/thread_count",
                            "id": "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/thread_count"
                        }
                    ],
                    "out": [
                        "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/vcf_list",
                        "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/time_metrics"
                    ],
                    "id": "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping"
                },
                {
                    "run": "#picard_sortvcf.cwl",
                    "in": [
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/job_uuid",
                            "id": "#gatk4_cohort_genotyping.cwl/picard_sortvcf/job_uuid"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/output_prefix",
                            "valueFrom": "$(self + '.srt')",
                            "id": "#gatk4_cohort_genotyping.cwl/picard_sortvcf/output_prefix"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/reference",
                            "valueFrom": "$(self.secondaryFiles[1])",
                            "id": "#gatk4_cohort_genotyping.cwl/picard_sortvcf/reference_dict"
                        },
                        {
                            "source": "#gatk4_cohort_genotyping.cwl/genomel_pdc_gatk4_cohort_genotyping/vcf_list",
                            "id": "#gatk4_cohort_genotyping.cwl/picard_sortvcf/vcf"
                        }
                    ],
                    "out": [
                        "#gatk4_cohort_genotyping.cwl/picard_sortvcf/sorted_vcf",
                        "#gatk4_cohort_genotyping.cwl/picard_sortvcf/time_metrics"
                    ],
                    "id": "#gatk4_cohort_genotyping.cwl/picard_sortvcf"
                }
            ],
            "id": "#gatk4_cohort_genotyping.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/aws_config"
                },
                {
                    "type": "File",
                    "id": "#main/aws_shared_credentials"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/bam_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bed_files"
                },
                {
                    "type": "boolean",
                    "id": "#main/cromwell_engine"
                },
                {
                    "type": "int",
                    "id": "#main/freebayes_thread_count"
                },
                {
                    "type": "int",
                    "id": "#main/gatk4_genotyping_thread_count"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/gvcf_files"
                },
                {
                    "type": "string",
                    "id": "#main/job_uuid"
                },
                {
                    "type": "int",
                    "id": "#main/number_of_chunks_for_freebayes"
                },
                {
                    "type": "int",
                    "id": "#main/number_of_chunks_for_gatk"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "id": "#main/upload_s3_bucket"
                },
                {
                    "type": "string",
                    "id": "#main/upload_s3_endpoint"
                },
                {
                    "type": "string",
                    "id": "#main/upload_s3_profile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/sort_freebayes/sorted_vcf",
                    "id": "#main/freebayes_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sort_gatk4/sorted_vcf",
                    "id": "#main/gatk4_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/extract_time_log/output",
                    "id": "#main/time_logs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sort_ensemble/sorted_vcf",
                    "id": "#main/variant_ensemble_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#extract_outputs.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/gatk4_cohort_genotyping/time_metrics_from_gatk4_cohort_genotyping",
                                "#main/gatk4_cohort_genotyping/time_metrics_from_picard_sortvcf",
                                "#main/gatk4_cohort_genotyping/time_metrics_from_selectvariants",
                                "#main/freebayes_cohort_genotyping/time_metrics_from_freebayes",
                                "#main/freebayes_cohort_genotyping/time_metrics_from_picard_sortvcf",
                                "#main/freebayes_cohort_genotyping/time_metrics_from_selectvariants",
                                "#main/variant_ensemble/time_metrics",
                                "#main/sort_gatk4/time_metrics",
                                "#main/sort_freebayes/time_metrics",
                                "#main/sort_ensemble/time_metrics",
                                "#main/upload_gatk4_vcf/time_metrics",
                                "#main/upload_gatk4_vcf_index/time_metrics",
                                "#main/upload_freebayes_vcf/time_metrics",
                                "#main/upload_freebayes_vcf_index/time_metrics",
                                "#main/upload_ensemble_vcf/time_metrics",
                                "#main/upload_ensemble_vcf_index/time_metrics"
                            ],
                            "valueFrom": "${\n  var log_list = []\n  for (var i = 0; i < self.length; i++){\n    if (Array.isArray(self[i])){\n      if (Array.isArray(self[i][0])){\n        for (var j = 0; j < self[i][0].length; j++){\n          log_list.push(self[i][0][j])\n        }\n      } else { log_list.push(self[i][0]) }\n    } else {\n      log_list.push(self[i])\n    }\n  }\n  return log_list\n}\n",
                            "id": "#main/extract_time_log/file_array"
                        }
                    ],
                    "out": [
                        "#main/extract_time_log/output"
                    ],
                    "id": "#main/extract_time_log"
                },
                {
                    "run": "#freebayes.cwl",
                    "scatter": [
                        "#main/freebayes_cohort_genotyping/bed_file",
                        "#main/freebayes_cohort_genotyping/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/bam_files",
                            "id": "#main/freebayes_cohort_genotyping/bam_files"
                        },
                        {
                            "source": "#main/bed_files",
                            "id": "#main/freebayes_cohort_genotyping/bed_file"
                        },
                        {
                            "source": "#main/cromwell_engine",
                            "id": "#main/freebayes_cohort_genotyping/cromwell_engine"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/freebayes_cohort_genotyping/job_uuid"
                        },
                        {
                            "source": "#main/number_of_chunks_for_freebayes",
                            "id": "#main/freebayes_cohort_genotyping/number_of_chunks"
                        },
                        {
                            "source": "#main/bed_files",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#main/freebayes_cohort_genotyping/output_prefix"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/freebayes_cohort_genotyping/reference"
                        },
                        {
                            "source": "#main/freebayes_thread_count",
                            "id": "#main/freebayes_cohort_genotyping/thread_count"
                        }
                    ],
                    "out": [
                        "#main/freebayes_cohort_genotyping/time_metrics_from_freebayes",
                        "#main/freebayes_cohort_genotyping/time_metrics_from_picard_sortvcf",
                        "#main/freebayes_cohort_genotyping/time_metrics_from_selectvariants",
                        "#main/freebayes_cohort_genotyping/freebayes_vcf"
                    ],
                    "id": "#main/freebayes_cohort_genotyping"
                },
                {
                    "run": "#gatk4_cohort_genotyping.cwl",
                    "scatter": [
                        "#main/gatk4_cohort_genotyping/bed_file",
                        "#main/gatk4_cohort_genotyping/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/bed_files",
                            "id": "#main/gatk4_cohort_genotyping/bed_file"
                        },
                        {
                            "source": "#main/cromwell_engine",
                            "id": "#main/gatk4_cohort_genotyping/cromwell_engine"
                        },
                        {
                            "source": "#main/gvcf_files",
                            "id": "#main/gatk4_cohort_genotyping/gvcf_files"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/gatk4_cohort_genotyping/job_uuid"
                        },
                        {
                            "source": "#main/number_of_chunks_for_gatk",
                            "id": "#main/gatk4_cohort_genotyping/number_of_chunks"
                        },
                        {
                            "source": "#main/bed_files",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#main/gatk4_cohort_genotyping/output_prefix"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/gatk4_cohort_genotyping/reference"
                        },
                        {
                            "source": "#main/gatk4_genotyping_thread_count",
                            "id": "#main/gatk4_cohort_genotyping/thread_count"
                        }
                    ],
                    "out": [
                        "#main/gatk4_cohort_genotyping/time_metrics_from_gatk4_cohort_genotyping",
                        "#main/gatk4_cohort_genotyping/time_metrics_from_picard_sortvcf",
                        "#main/gatk4_cohort_genotyping/time_metrics_from_selectvariants",
                        "#main/gatk4_cohort_genotyping/gatk4_cohort_genotyping_vcf"
                    ],
                    "id": "#main/gatk4_cohort_genotyping"
                },
                {
                    "run": "#picard_sortvcf.cwl",
                    "in": [
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/sort_ensemble/job_uuid"
                        },
                        {
                            "valueFrom": "genomel_cohort.variant_ensemble.genomel_all",
                            "id": "#main/sort_ensemble/output_prefix"
                        },
                        {
                            "source": "#main/reference",
                            "valueFrom": "$(self.secondaryFiles[1])",
                            "id": "#main/sort_ensemble/reference_dict"
                        },
                        {
                            "source": "#main/variant_ensemble/ensemble_vcf",
                            "valueFrom": "$([self])",
                            "id": "#main/sort_ensemble/vcf"
                        }
                    ],
                    "out": [
                        "#main/sort_ensemble/sorted_vcf",
                        "#main/sort_ensemble/time_metrics"
                    ],
                    "id": "#main/sort_ensemble"
                },
                {
                    "run": "#picard_sortvcf.cwl",
                    "in": [
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/sort_freebayes/job_uuid"
                        },
                        {
                            "valueFrom": "genomel_cohort.freebayes.genomel_all",
                            "id": "#main/sort_freebayes/output_prefix"
                        },
                        {
                            "source": "#main/reference",
                            "valueFrom": "$(self.secondaryFiles[1])",
                            "id": "#main/sort_freebayes/reference_dict"
                        },
                        {
                            "source": "#main/freebayes_cohort_genotyping/freebayes_vcf",
                            "id": "#main/sort_freebayes/vcf"
                        }
                    ],
                    "out": [
                        "#main/sort_freebayes/sorted_vcf",
                        "#main/sort_freebayes/time_metrics"
                    ],
                    "id": "#main/sort_freebayes"
                },
                {
                    "run": "#picard_sortvcf.cwl",
                    "in": [
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/sort_gatk4/job_uuid"
                        },
                        {
                            "valueFrom": "genomel_cohort.gatk4.genomel_all",
                            "id": "#main/sort_gatk4/output_prefix"
                        },
                        {
                            "source": "#main/reference",
                            "valueFrom": "$(self.secondaryFiles[1])",
                            "id": "#main/sort_gatk4/reference_dict"
                        },
                        {
                            "source": "#main/gatk4_cohort_genotyping/gatk4_cohort_genotyping_vcf",
                            "id": "#main/sort_gatk4/vcf"
                        }
                    ],
                    "out": [
                        "#main/sort_gatk4/sorted_vcf",
                        "#main/sort_gatk4/time_metrics"
                    ],
                    "id": "#main/sort_gatk4"
                },
                {
                    "run": "#awscli_upload.cwl",
                    "in": [
                        {
                            "source": "#main/aws_config",
                            "id": "#main/upload_ensemble_vcf/aws_config"
                        },
                        {
                            "source": "#main/aws_shared_credentials",
                            "id": "#main/upload_ensemble_vcf/aws_shared_credentials"
                        },
                        {
                            "source": "#main/sort_ensemble/sorted_vcf",
                            "id": "#main/upload_ensemble_vcf/input"
                        },
                        {
                            "source": "#main/upload_s3_endpoint",
                            "id": "#main/upload_ensemble_vcf/s3_endpoint"
                        },
                        {
                            "source": "#main/upload_s3_profile",
                            "id": "#main/upload_ensemble_vcf/s3_profile"
                        },
                        {
                            "source": [
                                "#main/upload_s3_bucket",
                                "#main/sort_ensemble/sorted_vcf"
                            ],
                            "valueFrom": "$(self[0])/$(self[1].basename)",
                            "id": "#main/upload_ensemble_vcf/s3uri"
                        }
                    ],
                    "out": [
                        "#main/upload_ensemble_vcf/output",
                        "#main/upload_ensemble_vcf/time_metrics"
                    ],
                    "id": "#main/upload_ensemble_vcf"
                },
                {
                    "run": "#awscli_upload.cwl",
                    "in": [
                        {
                            "source": "#main/aws_config",
                            "id": "#main/upload_ensemble_vcf_index/aws_config"
                        },
                        {
                            "source": "#main/aws_shared_credentials",
                            "id": "#main/upload_ensemble_vcf_index/aws_shared_credentials"
                        },
                        {
                            "source": "#main/sort_ensemble/sorted_vcf",
                            "valueFrom": "$(self.secondaryFiles[0])",
                            "id": "#main/upload_ensemble_vcf_index/input"
                        },
                        {
                            "source": "#main/upload_s3_endpoint",
                            "id": "#main/upload_ensemble_vcf_index/s3_endpoint"
                        },
                        {
                            "source": "#main/upload_s3_profile",
                            "id": "#main/upload_ensemble_vcf_index/s3_profile"
                        },
                        {
                            "source": [
                                "#main/upload_s3_bucket",
                                "#main/sort_ensemble/sorted_vcf"
                            ],
                            "valueFrom": "$(self[0])/$(self[1].secondaryFiles[0].basename)",
                            "id": "#main/upload_ensemble_vcf_index/s3uri"
                        }
                    ],
                    "out": [
                        "#main/upload_ensemble_vcf_index/output",
                        "#main/upload_ensemble_vcf_index/time_metrics"
                    ],
                    "id": "#main/upload_ensemble_vcf_index"
                },
                {
                    "run": "#awscli_upload.cwl",
                    "in": [
                        {
                            "source": "#main/aws_config",
                            "id": "#main/upload_freebayes_vcf/aws_config"
                        },
                        {
                            "source": "#main/aws_shared_credentials",
                            "id": "#main/upload_freebayes_vcf/aws_shared_credentials"
                        },
                        {
                            "source": "#main/sort_freebayes/sorted_vcf",
                            "id": "#main/upload_freebayes_vcf/input"
                        },
                        {
                            "source": "#main/upload_s3_endpoint",
                            "id": "#main/upload_freebayes_vcf/s3_endpoint"
                        },
                        {
                            "source": "#main/upload_s3_profile",
                            "id": "#main/upload_freebayes_vcf/s3_profile"
                        },
                        {
                            "source": [
                                "#main/upload_s3_bucket",
                                "#main/sort_freebayes/sorted_vcf"
                            ],
                            "valueFrom": "$(self[0])/$(self[1].basename)",
                            "id": "#main/upload_freebayes_vcf/s3uri"
                        }
                    ],
                    "out": [
                        "#main/upload_freebayes_vcf/output",
                        "#main/upload_freebayes_vcf/time_metrics"
                    ],
                    "id": "#main/upload_freebayes_vcf"
                },
                {
                    "run": "#awscli_upload.cwl",
                    "in": [
                        {
                            "source": "#main/aws_config",
                            "id": "#main/upload_freebayes_vcf_index/aws_config"
                        },
                        {
                            "source": "#main/aws_shared_credentials",
                            "id": "#main/upload_freebayes_vcf_index/aws_shared_credentials"
                        },
                        {
                            "source": "#main/sort_freebayes/sorted_vcf",
                            "valueFrom": "$(self.secondaryFiles[0])",
                            "id": "#main/upload_freebayes_vcf_index/input"
                        },
                        {
                            "source": "#main/upload_s3_endpoint",
                            "id": "#main/upload_freebayes_vcf_index/s3_endpoint"
                        },
                        {
                            "source": "#main/upload_s3_profile",
                            "id": "#main/upload_freebayes_vcf_index/s3_profile"
                        },
                        {
                            "source": [
                                "#main/upload_s3_bucket",
                                "#main/sort_freebayes/sorted_vcf"
                            ],
                            "valueFrom": "$(self[0])/$(self[1].secondaryFiles[0].basename)",
                            "id": "#main/upload_freebayes_vcf_index/s3uri"
                        }
                    ],
                    "out": [
                        "#main/upload_freebayes_vcf_index/output",
                        "#main/upload_freebayes_vcf_index/time_metrics"
                    ],
                    "id": "#main/upload_freebayes_vcf_index"
                },
                {
                    "run": "#awscli_upload.cwl",
                    "in": [
                        {
                            "source": "#main/aws_config",
                            "id": "#main/upload_gatk4_vcf/aws_config"
                        },
                        {
                            "source": "#main/aws_shared_credentials",
                            "id": "#main/upload_gatk4_vcf/aws_shared_credentials"
                        },
                        {
                            "source": "#main/sort_gatk4/sorted_vcf",
                            "id": "#main/upload_gatk4_vcf/input"
                        },
                        {
                            "source": "#main/upload_s3_endpoint",
                            "id": "#main/upload_gatk4_vcf/s3_endpoint"
                        },
                        {
                            "source": "#main/upload_s3_profile",
                            "id": "#main/upload_gatk4_vcf/s3_profile"
                        },
                        {
                            "source": [
                                "#main/upload_s3_bucket",
                                "#main/sort_gatk4/sorted_vcf"
                            ],
                            "valueFrom": "$(self[0])/$(self[1].basename)",
                            "id": "#main/upload_gatk4_vcf/s3uri"
                        }
                    ],
                    "out": [
                        "#main/upload_gatk4_vcf/output",
                        "#main/upload_gatk4_vcf/time_metrics"
                    ],
                    "id": "#main/upload_gatk4_vcf"
                },
                {
                    "run": "#awscli_upload.cwl",
                    "in": [
                        {
                            "source": "#main/aws_config",
                            "id": "#main/upload_gatk4_vcf_index/aws_config"
                        },
                        {
                            "source": "#main/aws_shared_credentials",
                            "id": "#main/upload_gatk4_vcf_index/aws_shared_credentials"
                        },
                        {
                            "source": "#main/sort_gatk4/sorted_vcf",
                            "valueFrom": "$(self.secondaryFiles[0])",
                            "id": "#main/upload_gatk4_vcf_index/input"
                        },
                        {
                            "source": "#main/upload_s3_endpoint",
                            "id": "#main/upload_gatk4_vcf_index/s3_endpoint"
                        },
                        {
                            "source": "#main/upload_s3_profile",
                            "id": "#main/upload_gatk4_vcf_index/s3_profile"
                        },
                        {
                            "source": [
                                "#main/upload_s3_bucket",
                                "#main/sort_gatk4/sorted_vcf"
                            ],
                            "valueFrom": "$(self[0])/$(self[1].secondaryFiles[0].basename)",
                            "id": "#main/upload_gatk4_vcf_index/s3uri"
                        }
                    ],
                    "out": [
                        "#main/upload_gatk4_vcf_index/output",
                        "#main/upload_gatk4_vcf_index/time_metrics"
                    ],
                    "id": "#main/upload_gatk4_vcf_index"
                },
                {
                    "run": "#vArmyKnife_variant_ensemble.cwl",
                    "in": [
                        {
                            "source": "#main/sort_freebayes/sorted_vcf",
                            "id": "#main/variant_ensemble/freebayes_vcf"
                        },
                        {
                            "source": "#main/sort_gatk4/sorted_vcf",
                            "id": "#main/variant_ensemble/gatk4_vcf"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/variant_ensemble/job_uuid"
                        },
                        {
                            "source": "#main/job_uuid",
                            "valueFrom": "$(self + '.variant_ensemble.vcf.gz')",
                            "id": "#main/variant_ensemble/output_name"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/variant_ensemble/reference"
                        }
                    ],
                    "out": [
                        "#main/variant_ensemble/ensemble_vcf",
                        "#main/variant_ensemble/time_metrics"
                    ],
                    "id": "#main/variant_ensemble"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
